@@ -45,14 +45,15 @@ landscape.coerce <- function(rland,noind=F)
 #is assigned to R's random number seed.  The type of RNG is inherited from the
 #calling environment
 #
-landscape.simulate <- function(Rland, numit, seed=-1, compress=FALSE, adj.lambda=0)
-  {
-    if (is.landscape(Rland))
-      {
-        if (!(seed<0))
-          {
-            set.seed(seed)
-          }
+landscape.simulate <- function(Rland, numit, seed=-1, compress=FALSE, adj.lambda=0,force=FALSE)
+{
+    if (force) rl=TRUE else rl=is.landscape(Rland)
+        if (rl)
+        {
+            if (!(seed<0))
+            {
+                set.seed(seed)
+            }
         Rland <- landscape.coerce(Rland)
         .Call("iterate_landscape",as.integer(numit),Rland,as.integer(compress),as.integer(adj.lambda),PACKAGE = "rmetasim")
       }
